package org.jeecg.modules.travelAdvance.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.travelAdvance.entity.TravelAdvance;
import org.jeecg.modules.travelAdvance.service.ITravelAdvanceService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 建议表
 * @Author: jeecg-boot
 * @Date:   2024-09-29
 * @Version: V1.0
 */
@Api(tags="建议表")
@RestController
@RequestMapping("/travelAdvance/travelAdvance")
@Slf4j
public class TravelAdvanceController extends JeecgController<TravelAdvance, ITravelAdvanceService> {
	@Autowired
	private ITravelAdvanceService travelAdvanceService;
	
	/**
	 * 分页列表查询
	 *
	 * @param travelAdvance
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "建议表-分页列表查询")
	@ApiOperation(value="建议表-分页列表查询", notes="建议表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<TravelAdvance>> queryPageList(TravelAdvance travelAdvance,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<TravelAdvance> queryWrapper = QueryGenerator.initQueryWrapper(travelAdvance, req.getParameterMap());
		Page<TravelAdvance> page = new Page<TravelAdvance>(pageNo, pageSize);
		IPage<TravelAdvance> pageList = travelAdvanceService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param travelAdvance
	 * @return
	 */
	@AutoLog(value = "建议表-添加")
	@ApiOperation(value="建议表-添加", notes="建议表-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody TravelAdvance travelAdvance) {
		travelAdvanceService.save(travelAdvance);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param travelAdvance
	 * @return
	 */
	@AutoLog(value = "建议表-编辑")
	@ApiOperation(value="建议表-编辑", notes="建议表-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody TravelAdvance travelAdvance) {
		travelAdvanceService.updateById(travelAdvance);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "建议表-通过id删除")
	@ApiOperation(value="建议表-通过id删除", notes="建议表-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		travelAdvanceService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "建议表-批量删除")
	@ApiOperation(value="建议表-批量删除", notes="建议表-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.travelAdvanceService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "建议表-通过id查询")
	@ApiOperation(value="建议表-通过id查询", notes="建议表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<TravelAdvance> queryById(@RequestParam(name="id",required=true) String id) {
		TravelAdvance travelAdvance = travelAdvanceService.getById(id);
		if(travelAdvance==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(travelAdvance);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param travelAdvance
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, TravelAdvance travelAdvance) {
        return super.exportXls(request, travelAdvance, TravelAdvance.class, "建议表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, TravelAdvance.class);
    }

}
